<!DOCTYPE TS><TS version="2.1" language="en_GB">
<context>
    <name>ChatRoomWidget</name>
    <message>
        <source>Choose a room to send messages or enter a command...</source>
        <translation>Choose a room to send messages or enter a command...</translation>
    </message>
    <message>
        <source>There&apos;s nothing to send</source>
        <translation>There&apos;s nothing to send</translation>
    </message>
    <message>
        <source>/join argument doesn&apos;t look like a room ID or alias</source>
        <translation>/join argument doesn&apos;t look like a room ID or alias</translation>
    </message>
    <message>
        <source>Sending a farewell message is not supported yet. If you intended to leave another room, switch to it and type /leave there.</source>
        <translation>Sending a farewell message is not supported yet. If you intended to leave another room, switch to it and type /leave there.</translation>
    </message>
    <message>
        <source>/forget must be followed by the room id/alias, even for the current room</source>
        <translation>/forget must be followed by the room id/alias, even for the current room</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t look like a room id or alias</source>
        <translation>%1 doesn&apos;t look like a room id or alias</translation>
    </message>
    <message>
        <source>/invite &lt;memberId&gt;</source>
        <translation>/invite &lt;memberId&gt;</translation>
    </message>
    <message>
        <source>/%1 &lt;userId&gt; &lt;reason&gt;</source>
        <translation>/%1 &lt;userId&gt; &lt;reason&gt;</translation>
    </message>
    <message>
        <source>%1 is not a member of this room</source>
        <translation>%1 is not a member of this room</translation>
    </message>
    <message>
        <source>/unban &lt;userId&gt;</source>
        <translation>/unban &lt;userId&gt;</translation>
    </message>
    <message>
        <source>/unban argument doesn&apos;t look like a user ID</source>
        <translation>/unban argument doesn&apos;t look like a user ID</translation>
    </message>
    <message>
        <source>/ignore &lt;userId&gt;</source>
        <translation>/ignore &lt;userId&gt;</translation>
    </message>
    <message>
        <source>/ignore argument doesn&apos;t look like a user ID</source>
        <translation>/ignore argument doesn&apos;t look like a user ID</translation>
    </message>
    <message>
        <source>Couldn&apos;t find user %1 on the server</source>
        <translation>Couldn&apos;t find user %1 on the server</translation>
    </message>
    <message>
        <source>/me needs an argument</source>
        <translation>/me needs an argument</translation>
    </message>
    <message>
        <source>/notice needs an argument</source>
        <translation>/notice needs an argument</translation>
    </message>
    <message>
        <source>/%1 &lt;memberId&gt; &lt;message&gt;</source>
        <translation>/%1 &lt;memberId&gt; &lt;message&gt;</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t seem to have joined room %2</source>
        <translation>%1 doesn&apos;t seem to have joined room %2</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t look like a user id or room alias</source>
        <translation>%1 doesn&apos;t look like a user id or room alias</translation>
    </message>
    <message>
        <source>/%1 &lt;memberId&gt;</source>
        <translation>/%1 &lt;memberId&gt;</translation>
    </message>
    <message>
        <source>Attach</source>
        <translation>Attach</translation>
    </message>
    <message>
        <source>Attach file</source>
        <translation>Attach file</translation>
    </message>
    <message>
        <source>Add a message to the file or just push Enter</source>
        <translation>Add a message to the file or just push Enter</translation>
    </message>
    <message>
        <source>Attaching %1</source>
        <translation>Attaching %1</translation>
    </message>
    <message>
        <source>Attaching cancelled</source>
        <translation>Attaching cancelled</translation>
    </message>
    <message>
        <source>There&apos;s no such /command outside of room.</source>
        <translation>There&apos;s no such /command outside of room.</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t look like a user id</source>
        <translation>%1 doesn&apos;t look like a user id</translation>
    </message>
    <message>
        <source>%1 doesn&apos;t look like a user ID</source>
        <translation>%1 doesn&apos;t look like a user ID</translation>
    </message>
    <message>
        <source>You should select a room to send messages.</source>
        <translation>You should select a room to send messages.</translation>
    </message>
    <message>
        <source>Send a message (over %1) or enter a command...</source>
        <translation>Send a message (over %1) or enter a command...</translation>
    </message>
    <message>
        <source>No completions</source>
        <translation>No completions</translation>
    </message>
    <message numerus="yes">
        <source>%Ln more completions</source>
        <translation>
            <numerusform>%Ln more completion</numerusform>
            <numerusform>%Ln more completions</numerusform>
        </translation>
    </message>
    <message>
        <source>Next completion:</source>
        <translation>Next completion:</translation>
    </message>
    <message>
        <source>Currently typing:</source>
        <translation>Currently typing:</translation>
    </message>
    <message>
        <source>At character %1: %2</source>
        <translation>At character %1: %2</translation>
    </message>
    <message>
        <source>%L1 more</source>
        <translation>%L1 more</translation>
    </message>
    <message>
        <source>%1 is not readable or not a file</source>
        <translation>%1 is not readable or not a file</translation>
    </message>
    <message>
        <source>Attaching the pasted image</source>
        <translation>Attaching the pasted image</translation>
    </message>
    <message>
        <source>Can&apos;t attach a file without a selected room</source>
        <translation>Can&apos;t attach a file without a selected room</translation>
    </message>
    <message>
        <source>Cannot insert HTML - it&apos;s either invalid or unsupported</source>
        <translation>Cannot insert HTML — it&apos;s either invalid or unsupported</translation>
    </message>
    <message>
        <source>Unknown /command. If you intended to send a message, start with // instead of /</source>
        <translation>Unknown /command. If you intended to send a message, start with // instead of /</translation>
    </message>
</context>
<context>
    <name>CreateRoomDialog</name>
    <message>
        <source>Create room</source>
        <translation>Create room</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Add</translation>
    </message>
    <message>
        <source>Invite user(s)</source>
        <translation>Invite user(s)</translation>
    </message>
    <message>
        <source>Creating the room, please wait</source>
        <translation>Creating the room, please wait</translation>
    </message>
    <message>
        <source>Please fill the fields as desired. None are mandatory</source>
        <translation>Please fill the fields as desired. None are mandatory</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remove</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Applying changes, please wait</source>
        <translation>Applying changes, please wait</translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Stay logged in</source>
        <translation>Stay logged in</translation>
    </message>
    <message>
        <source>Matrix ID</source>
        <translation>Matrix ID</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Device name</source>
        <translation>Device name</translation>
    </message>
    <message>
        <source>Connect to server</source>
        <translation>Connect to server</translation>
    </message>
    <message>
        <source>Connecting and logging in, please wait</source>
        <translation>Connecting and logging in, please wait</translation>
    </message>
    <message>
        <source>Re-login</source>
        <translation>Re-login</translation>
    </message>
    <message>
        <source>Restoring access, please wait</source>
        <translation>Restoring access, please wait</translation>
    </message>
    <message>
        <source>Resolving the homeserver...</source>
        <translation>Resolving the homeserver...</translation>
    </message>
    <message>
        <source>The server URL doesn&apos;t look valid</source>
        <translation>The server URL doesn&apos;t look valid</translation>
    </message>
    <message>
        <source>Login with SSO</source>
        <translation>Login with SSO</translation>
    </message>
    <message>
        <source>The homeserver is available</source>
        <translation>The homeserver is available</translation>
    </message>
    <message>
        <source>Could not connect to the homeserver</source>
        <translation>Could not connect to the homeserver</translation>
    </message>
    <message>
        <source>No supported login flows</source>
        <translation>No supported login flows</translation>
    </message>
    <message>
        <source>Single sign-on</source>
        <translation>Single sign-on</translation>
    </message>
    <message>
        <source>Quaternion couldn&apos;t automatically open the single sign-on URL. Please copy and paste it to the right application (usually a web browser):</source>
        <translation>Quaternion couldn&apos;t automatically open the single sign-on URL. Please copy and paste it to the right application (usually a web browser):</translation>
    </message>
    <message>
        <source>After authentication, the browser will follow the temporary local address setup by Quaternion to conclude the login sequence.</source>
        <translation>After authentication, the browser will follow the temporary local address setup by Quaternion to conclude the login sequence.</translation>
    </message>
    <message>
        <source>Getting supported login flows...</source>
        <translation>Getting supported login flows...</translation>
    </message>
    <message>
        <source>This account is logged in already</source>
        <translation>This account is logged in already</translation>
    </message>
    <message>
        <source>(none)</source>
        <translation>(none)</translation>
    </message>
    <message>
        <source>Saved device id</source>
        <translation>Saved device id</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Loading...</source>
        <translation>Loading...</translation>
    </message>
    <message>
        <source>&amp;Accounts</source>
        <translation>&amp;Accounts</translation>
    </message>
    <message>
        <source>&amp;Login...</source>
        <translation>&amp;Login...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quit</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;View</translation>
    </message>
    <message>
        <source>&amp;Display in timeline</source>
        <translation>&amp;Display in timeline</translation>
    </message>
    <message>
        <source>Normal &amp;join/leave events</source>
        <translation>Normal &amp;join/leave events</translation>
    </message>
    <message>
        <source>&amp;Redacted events</source>
        <translation>&amp;Redacted events</translation>
    </message>
    <message>
        <source>Show redacted events in the timeline as &apos;Redacted&apos; instead of hiding them entirely</source>
        <translation>Show redacted events in the timeline as &apos;Redacted&apos; instead of hiding them entirely</translation>
    </message>
    <message>
        <source>&amp;No-effect activity</source>
        <translation>&amp;No-effect activity</translation>
    </message>
    <message>
        <source>Edit tags order</source>
        <translation>Edit tags order</translation>
    </message>
    <message>
        <source>&amp;Room</source>
        <translation>&amp;Room</translation>
    </message>
    <message>
        <source>Change room &amp;settings...</source>
        <translation>Change room &amp;settings...</translation>
    </message>
    <message>
        <source>Create &amp;new room...</source>
        <translation>Create &amp;new room...</translation>
    </message>
    <message>
        <source>&amp;Join room...</source>
        <translation>&amp;Join room...</translation>
    </message>
    <message>
        <source>&amp;Close current room</source>
        <translation>&amp;Close current room</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Settings</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;About</translation>
    </message>
    <message>
        <source>&amp;Highlight only</source>
        <translation>&amp;Highlight only</translation>
    </message>
    <message>
        <source>Notifications are entirely suppressed</source>
        <translation>Notifications are entirely suppressed</translation>
    </message>
    <message>
        <source>&amp;Non-intrusive</source>
        <translation>&amp;Non-intrusive</translation>
    </message>
    <message>
        <source>Show notifications but do not activate the window</source>
        <translation>Show notifications but do not activate the window</translation>
    </message>
    <message>
        <source>&amp;Full</source>
        <translation>&amp;Full</translation>
    </message>
    <message>
        <source>Show notifications and activate the window</source>
        <translation>Show notifications and activate the window</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notifications</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Default</translation>
    </message>
    <message>
        <source>The layout with author labels above blocks of messages</source>
        <translation>The layout with author labels above blocks of messages</translation>
    </message>
    <message>
        <source>The layout with author labels to the left from each message</source>
        <translation>The layout with author labels to the left from each message</translation>
    </message>
    <message>
        <source>Timeline layout</source>
        <translation>Timeline layout</translation>
    </message>
    <message>
        <source>Load full-size images at once</source>
        <translation>Load full-size images at once</translation>
    </message>
    <message>
        <source>Automatically download a full-size image instead of a thumbnail</source>
        <translation>Automatically download a full-size image instead of a thumbnail</translation>
    </message>
    <message>
        <source>Configure &amp;network proxy...</source>
        <translation>Configure &amp;network proxy...</translation>
    </message>
    <message>
        <source>Logged out as %1</source>
        <translation>Logged out as %1</translation>
    </message>
    <message>
        <source>Sync failed</source>
        <translation>Sync failed</translation>
    </message>
    <message>
        <source>The last sync of account %1 has failed with error: %2</source>
        <translation>The last sync of account %1 has failed with error: %2</translation>
    </message>
    <message>
        <source>The last sync has failed with error: %1</source>
        <translation>The last sync has failed with error: %1</translation>
    </message>
    <message>
        <source>Clicking &apos;Retry&apos; will attempt to resume synchronisation;
Clicking &apos;Cancel&apos; will stop further synchronisation of this account until logout or Quaternion restart.</source>
        <translation>Clicking &apos;Retry&apos; will attempt to resume synchronization;
Clicking &apos;Cancel&apos; will stop further synchronization of this account until logout or Quaternion restart.</translation>
    </message>
    <message>
        <source>Before this server can process your information, you have to agree with its terms and conditions; please click the button below to open the web page where you can do that</source>
        <translation>Before this server can process your information, you have to agree with its terms and conditions; please click the button below to open the web page where you can do that</translation>
    </message>
    <message>
        <source>Open web page</source>
        <translation>Open web page</translation>
    </message>
    <message>
        <source>About Quaternion</source>
        <translation>About Quaternion</translation>
    </message>
    <message>
        <source>Welcome to Quaternion</source>
        <translation>Welcome to Quaternion</translation>
    </message>
    <message>
        <source>Joined %1 as %2</source>
        <translation>Joined %1 as %2</translation>
    </message>
    <message>
        <source>Couldn&apos;t connect to the server as %1; will retry within %2 seconds</source>
        <translation>Couldn&apos;t connect to the server as %1; will retry within %2 seconds</translation>
    </message>
    <message>
        <source>Reconnecting...</source>
        <translation>Reconnecting...</translation>
    </message>
    <message>
        <source>No SSL support</source>
        <translation>No SSL support</translation>
    </message>
    <message>
        <source>Your SSL configuration does not allow Quaternion to establish secure connections.</source>
        <translation>Your SSL configuration does not allow Quaternion to establish secure connections.</translation>
    </message>
    <message>
        <source>SSL error</source>
        <translation>SSL error</translation>
    </message>
    <message>
        <source>Proxy needs authentication</source>
        <translation>Proxy needs authentication</translation>
    </message>
    <message>
        <source>Authenticate</source>
        <translation>Authenticate</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>User name</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>&amp;Thanks</source>
        <translation>&amp;Thanks</translation>
    </message>
    <message>
        <source>Original project author: %1</source>
        <translation>Original project author: %1</translation>
    </message>
    <message>
        <source>Web page</source>
        <translation>Web page</translation>
    </message>
    <message>
        <source>Project leader: %1</source>
        <translation>Project leader: %1</translation>
    </message>
    <message>
        <source>Contributors:</source>
        <translation>Contributors:</translation>
    </message>
    <message>
        <source>Quaternion contributors @ GitHub</source>
        <translation>Quaternion contributors @ GitHub</translation>
    </message>
    <message>
        <source>Quaternion translators @ Lokalise.co</source>
        <translation>Quaternion translators @ Lokalise.co</translation>
    </message>
    <message>
        <source>Made with:</source>
        <translation>Made with:</translation>
    </message>
    <message>
        <source>Show join and leave events</source>
        <translation>Show join and leave events</translation>
    </message>
    <message>
        <source>Use shuttle scrollbar (requires restart)</source>
        <translation>Use shuttle scrollbar (requires restart)</translation>
    </message>
    <message>
        <source>Control scroll velocity instead of position with the timeline scrollbar</source>
        <translation>Control scroll velocity instead of position with the timeline scrollbar</translation>
    </message>
    <message>
        <source>Request URL: %1
Response:
%2</source>
        <translation>Request URL: %1
Response:
%2</translation>
    </message>
    <message>
        <source>Close to tray</source>
        <translation>Close to tray</translation>
    </message>
    <message>
        <source>Make close button [X] minimize to tray instead of closing main window</source>
        <translation>Make close button [X] minimize to tray instead of closing main window</translation>
    </message>
    <message>
        <source>Show/hide meaningless activity (join-leave pairs and redacted events between)</source>
        <translation>Show/hide meaningless activity (join-leave pairs and redacted events between)</translation>
    </message>
    <message>
        <source>Built from Git, commit SHA:</source>
        <translation>Built from Git, commit SHA:</translation>
    </message>
    <message>
        <source>Library commit SHA:</source>
        <translation>Library commit SHA:</translation>
    </message>
    <message>
        <source>Open room...</source>
        <translation>Open room...</translation>
    </message>
    <message>
        <source>Open room</source>
        <translation>Open room</translation>
    </message>
    <message>
        <source>Open a room from the room list</source>
        <translation>Open a room from the room list</translation>
    </message>
    <message>
        <source>Couldn&apos;t delete access token</source>
        <translation>Couldn&apos;t delete access token</translation>
    </message>
    <message>
        <source>Open direct chat?</source>
        <translation>Open direct chat?</translation>
    </message>
    <message>
        <source>Open direct chat with user %1?</source>
        <translation>Open direct chat with user %1?</translation>
    </message>
    <message>
        <source>Room not found</source>
        <translation>Room not found</translation>
    </message>
    <message>
        <source>There&apos;s no room %1 in the room list. Check the spelling and the account.</source>
        <translation>There&apos;s no room %1 in the room list. Check the spelling and the account.</translation>
    </message>
    <message>
        <source>Confirm your account to open %1</source>
        <translation>Confirm your account to open %1</translation>
    </message>
    <message>
        <source>Confirm account</source>
        <translation>Confirm account</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Account</translation>
    </message>
    <message>
        <source>Room ID (starting with !)
or alias (starting with #)</source>
        <translation>Room ID (starting with !)
or alias (starting with #)</translation>
    </message>
    <message>
        <source>Confirm account to join %1</source>
        <translation>Confirm account to join %1</translation>
    </message>
    <message>
        <source>Edit quote style</source>
        <translation>Edit quote style</translation>
    </message>
    <message>
        <source>Markdown (prepend each line with &gt;)</source>
        <translation>Markdown (prepend each line with &gt;)</translation>
    </message>
    <message>
        <source>Custom (apply regex from the config file)</source>
        <translation>Custom (apply regex from the config file)</translation>
    </message>
    <message>
        <source>Locale&apos;s default (%1)</source>
        <translation>Locale&apos;s default (%1)</translation>
    </message>
    <message>
        <source>Example quote</source>
        <translation>Example quote</translation>
    </message>
    <message>
        <source>Choose the default style of quotes</source>
        <translation>Choose the default style of quotes</translation>
    </message>
    <message>
        <source>Special thanks to %1 for all the testing effort</source>
        <translation>Special thanks to %1 for all the testing effort</translation>
    </message>
    <message>
        <source>libQuotient contributors @ GitHub</source>
        <translation>libQuotient contributors @ GitHub</translation>
    </message>
    <message>
        <source>First sync completed for %1</source>
        <translation>First sync completed for %1</translation>
    </message>
    <message>
        <source>Quaternion couldn&apos;t delete the access token from the keychain.</source>
        <translation>Quaternion couldn&apos;t delete the access token from the keychain.</translation>
    </message>
    <message>
        <source>No application for the link</source>
        <translation>No application for the link</translation>
    </message>
    <message>
        <source>Your operating system could not find an application for the link.</source>
        <translation>Your operating system could not find an application for the link.</translation>
    </message>
    <message>
        <source>External link confirmation</source>
        <translation>External link confirmation</translation>
    </message>
    <message>
        <source>An external application will be opened to visit a non-Matrix link:

%1

Is that right?</source>
        <translation>An external application will be opened to visit a non-Matrix link:

%1

Is that right?</translation>
    </message>
    <message>
        <source>Do not ask again</source>
        <translation>Do not ask again</translation>
    </message>
    <message>
        <source>Malformed or empty Matrix id</source>
        <translation>Malformed or empty Matrix id</translation>
    </message>
    <message>
        <source>%1 is not a correct Matrix identifier</source>
        <translation>%1 is not a correct Matrix identifier</translation>
    </message>
    <message>
        <source>Please connect to a server</source>
        <translation>Please connect to a server</translation>
    </message>
    <message>
        <source>Confirm your account to open a direct chat with %1</source>
        <translation>Confirm your account to open a direct chat with %1</translation>
    </message>
    <message>
        <source>User &amp;profiles...</source>
        <translation>User &amp;profiles...</translation>
    </message>
    <message>
        <source>Log&amp;out</source>
        <translation>Log&amp;out</translation>
    </message>
    <message>
        <source>Invite events</source>
        <translation>Invite events</translation>
    </message>
    <message>
        <source>Show invite and withdrawn invitation events</source>
        <translation>Show invite and withdrawn invitation events</translation>
    </message>
    <message>
        <source>Ban events</source>
        <translation>Ban events</translation>
    </message>
    <message>
        <source>Show ban and unban events</source>
        <translation>Show ban and unban events</translation>
    </message>
    <message>
        <source>Changes in display na&amp;me</source>
        <translation>Changes in display na&amp;me</translation>
    </message>
    <message>
        <source>Show display name change</source>
        <translation>Show display name change</translation>
    </message>
    <message>
        <source>Avatar &amp;changes</source>
        <translation>Avatar &amp;changes</translation>
    </message>
    <message>
        <source>Show avatar update events</source>
        <translation>Show avatar update events</translation>
    </message>
    <message>
        <source>Room alias &amp;updates</source>
        <translation>Room alias &amp;updates</translation>
    </message>
    <message>
        <source>Show room alias updates events</source>
        <translation>Show room alias updates events</translation>
    </message>
    <message>
        <source>Un&amp;known event types</source>
        <translation>Un&amp;known event types</translation>
    </message>
    <message>
        <source>Show/hide unknown event types</source>
        <translation>Show/hide unknown event types</translation>
    </message>
    <message>
        <source>Tags can be wildcarded by * next to dot(s)
Clear the box to reset to defaults
Special tags starting with &quot;im.quotient.&quot; are: %1
User-defined tags should start with &quot;u.&quot;</source>
        <translation>Tags can be wildcarded by * next to dot(s)
Clear the box to reset to defaults
Special tags starting with &quot;im.quotient.&quot; are: %1
User-defined tags should start with &quot;u.&quot;</translation>
    </message>
    <message>
        <source>&amp;About Quaternion</source>
        <translation>&amp;About Quaternion</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>About &amp;Qt</translation>
    </message>
    <message>
        <source>Use Breeze style (requires restart)</source>
        <translation>Use Breeze style (requires restart)</translation>
    </message>
    <message>
        <source>Force use Breeze style and icon theme</source>
        <translation>Force use Breeze style and icon theme</translation>
    </message>
    <message>
        <source>Chat with user</source>
        <translation>Chat with user</translation>
    </message>
    <message>
        <source>Can&apos;t open</source>
        <translation>Can&apos;t open</translation>
    </message>
    <message>
        <source>Could not resolve id</source>
        <translation>Could not resolve id</translation>
    </message>
    <message>
        <source>Could not find an external application to open the URI:</source>
        <translation>Could not find an external application to open the URI:</translation>
    </message>
    <message>
        <source>Could not resolve Matrix identifier</source>
        <translation>Could not resolve Matrix identifier</translation>
    </message>
    <message>
        <source>Incorrect action on a Matrix resource</source>
        <translation>Incorrect action on a Matrix resource</translation>
    </message>
    <message>
        <source>The URI contains an action &apos;%1&apos; that cannot be applied to Matrix resource %2</source>
        <translation>The URI contains an action &apos;%1&apos; that cannot be applied to Matrix resource %2</translation>
    </message>
    <message>
        <source>Room or user ID, room alias,
Matrix URI or matrix.to link</source>
        <translation>Room or user ID, room alias,
Matrix URI or matrix.to link</translation>
    </message>
    <message>
        <source>Go to room</source>
        <translation>Go to room</translation>
    </message>
    <message>
        <source>Join room</source>
        <translation>Join room</translation>
    </message>
    <message>
        <source>Quaternion project contributors</source>
        <translation>Quaternion project contributors</translation>
    </message>
    <message>
        <source>Felix Rohrbach</source>
        <translation>Felix Rohrbach</translation>
    </message>
    <message>
        <source>Alexey &quot;Kitsune&quot; Rusakov</source>
        <translation>Alexey &quot;Kitsune&quot; Rusakov</translation>
    </message>
    <message>
        <source>Confirm opening external links</source>
        <translation>Confirm opening external links</translation>
    </message>
    <message>
        <source>Show a confirmation box before opening non-Matrix links in an external application</source>
        <translation>Show a confirmation box before opening non-Matrix links in an external application</translation>
    </message>
    <message numerus="yes">
        <source>Loading %Ln accounts, please wait</source>
        <translation>
            <numerusform>Loading %Ln account, please wait</numerusform>
            <numerusform>Loading %Ln accounts, please wait</numerusform>
        </translation>
    </message>
    <message>
        <source>Account %1 is synchronised, have a good chat</source>
        <translation>Account %1 is synchronised, have a good chat</translation>
    </message>
    <message numerus="yes">
        <source>All %Ln accounts synchronised, have a good chat</source>
        <translation>
            <numerusform>%Ln account synchronised, have a good chat</numerusform>
            <numerusform>All %Ln accounts synchronised, have a good chat</numerusform>
        </translation>
    </message>
    <message>
        <source>&amp;Room list</source>
        <translation>&amp;Room list</translation>
    </message>
    <message>
        <source>&amp;Member list</source>
        <translation>&amp;Member list</translation>
    </message>
    <message>
        <source>Dock panels</source>
        <translation>Dock panels</translation>
    </message>
    <message>
        <source>Can&apos;t find the event without knowing the room</source>
        <translation>Can&apos;t find the event without knowing the room</translation>
    </message>
    <message>
        <source>Open the room that has this event to scroll to %1</source>
        <translation>Open the room that has this event to scroll to %1</translation>
    </message>
</context>
<context>
    <name>MessageEventModel</name>
    <message>
        <source>Today</source>
        <translation>Today</translation>
    </message>
    <message>
        <source>Yesterday</source>
        <translation>Yesterday</translation>
    </message>
    <message>
        <source>The day before yesterday</source>
        <translation>The day before yesterday</translation>
    </message>
    <message>
        <source>Redacted</source>
        <translation>Redacted</translation>
    </message>
    <message>
        <source>Redacted: %1</source>
        <translation>Redacted: %1</translation>
    </message>
    <message>
        <source>a file</source>
        <translation>a file</translation>
    </message>
    <message>
        <source>invited %1 to the room</source>
        <translation>invited %1 to the room</translation>
    </message>
    <message>
        <source>joined the room</source>
        <translation>joined the room</translation>
    </message>
    <message>
        <source>cleared the display name</source>
        <translation>cleared the display name</translation>
    </message>
    <message>
        <source>changed the display name to %1</source>
        <translation>changed the display name to %1</translation>
    </message>
    <message>
        <source>cleared the avatar</source>
        <translation>cleared the avatar</translation>
    </message>
    <message>
        <source>updated the avatar</source>
        <translation>updated the avatar</translation>
    </message>
    <message>
        <source>unbanned %1</source>
        <translation>unbanned %1</translation>
    </message>
    <message>
        <source>self-unbanned</source>
        <translation>self-unbanned</translation>
    </message>
    <message>
        <source>left the room</source>
        <translation>left the room</translation>
    </message>
    <message>
        <source>self-banned from the room</source>
        <translation>self-banned from the room</translation>
    </message>
    <message>
        <source>knocked</source>
        <translation>knocked</translation>
    </message>
    <message>
        <source>made something unknown</source>
        <translation>made something unknown</translation>
    </message>
    <message>
        <source>cleared the room main alias</source>
        <translation>cleared the room main alias</translation>
    </message>
    <message>
        <source>set the room main alias to: %1</source>
        <translation>set the room main alias to: %1</translation>
    </message>
    <message>
        <source>cleared the room name</source>
        <translation>cleared the room name</translation>
    </message>
    <message>
        <source>set the room name to: %1</source>
        <translation>set the room name to: %1</translation>
    </message>
    <message>
        <source>cleared the topic</source>
        <translation>cleared the topic</translation>
    </message>
    <message>
        <source>set the topic to: %1</source>
        <translation>set the topic to: %1</translation>
    </message>
    <message>
        <source>changed the room avatar</source>
        <translation>changed the room avatar</translation>
    </message>
    <message>
        <source>activated End-to-End Encryption</source>
        <translation>activated End-to-End Encryption</translation>
    </message>
    <message>
        <source>withdrew %1&apos;s invitation</source>
        <translation>withdrew %1&apos;s invitation</translation>
    </message>
    <message>
        <source>rejected the invitation</source>
        <translation>rejected the invitation</translation>
    </message>
    <message>
        <source>updated the database</source>
        <translation>updated the database</translation>
    </message>
    <message>
        <source>updated %1 state</source>
        <translation>updated %1 state</translation>
    </message>
    <message>
        <source>updated %1 state for %2</source>
        <translation>updated %1 state for %2</translation>
    </message>
    <message>
        <source>Unknown event</source>
        <translation>Unknown event</translation>
    </message>
    <message>
        <source>upgraded the room to version %1</source>
        <translation>upgraded the room to version %1</translation>
    </message>
    <message>
        <source>created the room, version %1</source>
        <translation>created the room, version %1</translation>
    </message>
    <message>
        <source>banned %1 from the room: %2</source>
        <translation>banned %1 from the room: %2</translation>
    </message>
    <message>
        <source>kicked %1 from the room: %2</source>
        <translation>kicked %1 from the room: %2</translation>
    </message>
    <message>
        <source>upgraded the room: %1</source>
        <translation>upgraded the room: %1</translation>
    </message>
    <message>
        <source> and </source>
        <translation> and </translation>
    </message>
    <message numerus="yes">
        <source>%Ln more member(s)</source>
        <translation>
            <numerusform>%Ln more member</numerusform>
            <numerusform>%Ln more members</numerusform>
        </translation>
    </message>
    <message>
        <source>(repeated)</source>
        <translation>(repeated)</translation>
    </message>
    <message>
        <source>kicked %1 from the room</source>
        <translation>kicked %1 from the room</translation>
    </message>
    <message>
        <source>(loading)</source>
        <translation>(loading)</translation>
    </message>
    <message>
        <source>Could not decrypt the event</source>
        <translation>Could not decrypt the event</translation>
    </message>
</context>
<context>
    <name>NetworkConfigDialog</name>
    <message>
        <source>Network proxy settings</source>
        <translation>Network proxy settings</translation>
    </message>
    <message>
        <source>&amp;Override system defaults</source>
        <translation>&amp;Override system defaults</translation>
    </message>
    <message>
        <source>&amp;No proxy</source>
        <translation>&amp;No proxy</translation>
    </message>
    <message>
        <source>&amp;HTTP(S) proxy</source>
        <translation>&amp;HTTP(S) proxy</translation>
    </message>
    <message>
        <source>&amp;SOCKS5 proxy</source>
        <translation>&amp;SOCKS5 proxy</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Host</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>User name</translation>
    </message>
</context>
<context>
    <name>RoomDialogBase</name>
    <message>
        <source>Publish room in room directory</source>
        <translation>Publish room in room directory</translation>
    </message>
    <message>
        <source>Allow guest accounts to join the room</source>
        <translation>Allow guest accounts to join the room</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Account</translation>
    </message>
    <message>
        <source>Room name</source>
        <translation>Room name</translation>
    </message>
    <message>
        <source>Primary alias</source>
        <translation>Primary alias</translation>
    </message>
    <message>
        <source>Topic</source>
        <translation>Topic</translation>
    </message>
    <message>
        <source>About room versions</source>
        <translation>About room versions</translation>
    </message>
    <message>
        <source>(loading)</source>
        <translation>(loading)</translation>
    </message>
    <message>
        <source>default</source>
        <translation>default</translation>
    </message>
    <message>
        <source>stable</source>
        <translation>stable</translation>
    </message>
    <message>
        <source>Room version</source>
        <translation>Room version</translation>
    </message>
    <message>
        <source>Continue with unstable version?</source>
        <translation>Continue with unstable version?</translation>
    </message>
    <message>
        <source>You are using an UNSTABLE room version (%1). The server may stop supporting it at any moment. Do you still want to use this version?</source>
        <translation>You are using an UNSTABLE room version (%1). The server may stop supporting it at any moment. Do you still want to use this version?</translation>
    </message>
    <message>
        <source>(no available room versions)</source>
        <translation>(no available room versions)</translation>
    </message>
</context>
<context>
    <name>RoomListDock</name>
    <message>
        <source>Mark room as read</source>
        <translation>Mark room as read</translation>
    </message>
    <message>
        <source>Add tags...</source>
        <translation>Add tags...</translation>
    </message>
    <message>
        <source>Join room</source>
        <translation>Join room</translation>
    </message>
    <message>
        <source>Forget room</source>
        <translation>Forget room</translation>
    </message>
    <message>
        <source>Remove tag</source>
        <translation>Remove tag</translation>
    </message>
    <message>
        <source>Reject invitation</source>
        <translation>Reject invitation</translation>
    </message>
    <message>
        <source>Leave room</source>
        <translation>Leave room</translation>
    </message>
    <message>
        <source>Enter new tags for the room</source>
        <translation>Enter new tags for the room</translation>
    </message>
    <message>
        <source>Enter tags to add to this room, one tag per line</source>
        <translation>Enter tags to add to this room, one tag per line</translation>
    </message>
    <message>
        <source>Change room &amp;settings...</source>
        <translation>Change room &amp;settings...</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Add</translation>
    </message>
    <message>
        <source>Copy room link to clipboard</source>
        <translation>Copy room link to clipboard</translation>
    </message>
    <message>
        <source>Rooms (%L1)</source>
        <translation>Rooms (%L1)</translation>
    </message>
    <message>
        <source>Forget this room?</source>
        <translation>Forget this room?</translation>
    </message>
    <message>
        <source>Are you sure you want to forget room %1?</source>
        <translation>Are you sure you want to forget room %1?</translation>
    </message>
</context>
<context>
    <name>RoomListModel</name>
    <message>
        <source>Invited</source>
        <translation>Invited</translation>
    </message>
    <message>
        <source>Low priority</source>
        <translation>Low priority</translation>
    </message>
    <message>
        <source>People</source>
        <translation>People</translation>
    </message>
    <message>
        <source>Ungrouped rooms</source>
        <translation>Ungrouped rooms</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Left</translation>
    </message>
    <message numerus="yes">
        <source>%1 (%Ln room(s))</source>
        <translation>
            <numerusform>%1 (%Ln room)</numerusform>
            <numerusform>%1 (%Ln rooms)</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 (as %2)</source>
        <translation>%1 (as %2)</translation>
    </message>
    <message>
        <source>Main alias: %1</source>
        <translation>Main alias: %1</translation>
    </message>
    <message>
        <source>Direct chat with %1</source>
        <translation>Direct chat with %1</translation>
    </message>
    <message>
        <source>The room enforces encryption</source>
        <translation>The room enforces encryption</translation>
    </message>
    <message>
        <source>Favourites</source>
        <translation>Favourites</translation>
    </message>
    <message>
        <source>This room&apos;s version is unstable!</source>
        <translation>This room&apos;s version is unstable!</translation>
    </message>
    <message>
        <source>Consider upgrading to a stable version (use room settings for that)</source>
        <translation>Consider upgrading to a stable version (use room settings for that)</translation>
    </message>
    <message>
        <source>Server notices</source>
        <translation>Server notices</translation>
    </message>
    <message>
        <source>Joined: %L1</source>
        <translation>Joined: %L1</translation>
    </message>
    <message>
        <source>Invited: %L1</source>
        <translation>Invited: %L1</translation>
    </message>
    <message>
        <source>(maybe more)</source>
        <translation>(maybe more)</translation>
    </message>
    <message>
        <source>Events after fully read marker: %L1</source>
        <translation>Events after fully read marker: %L1</translation>
    </message>
    <message>
        <source>Unread events/highlights since read receipt: %L1/%L2</source>
        <translation>Unread events/highlights since read receipt: %L1/%L2</translation>
    </message>
    <message>
        <source>Unread events since read receipt: %L1</source>
        <translation>Unread events since read receipt: %L1</translation>
    </message>
    <message>
        <source>Room id: %1</source>
        <translation>Room id: %1</translation>
    </message>
    <message>
        <source>You joined this room as %1</source>
        <translation>You joined this room as %1</translation>
    </message>
    <message>
        <source>You were invited into this room as %1</source>
        <translation>You were invited into this room as %1</translation>
    </message>
    <message>
        <source>You left this room as %1</source>
        <translation>You left this room as %1</translation>
    </message>
</context>
<context>
    <name>RoomSettingsDialog</name>
    <message>
        <source>Room settings: %1</source>
        <translation>Room settings: %1</translation>
    </message>
    <message>
        <source>Update room</source>
        <translation>Update room</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Tags</translation>
    </message>
    <message>
        <source>This version is unstable! Consider upgrading.</source>
        <translation>This version is unstable! Consider upgrading.</translation>
    </message>
    <message>
        <source>Upgrade</source>
        <translation>Upgrade</translation>
    </message>
    <message>
        <source>Choose new room version</source>
        <translation>Choose new room version</translation>
    </message>
    <message>
        <source>You are about to upgrade %1.
This operation cannot be reverted.</source>
        <translation>You are about to upgrade %1.
This operation cannot be reverted.</translation>
    </message>
    <message>
        <source>Creating the new room version, please wait</source>
        <translation>Creating the new room version, please wait</translation>
    </message>
    <message>
        <source>Room identifier</source>
        <translation>Room identifier</translation>
    </message>
</context>
<context>
    <name>UserListDock</name>
    <message>
        <source>Users</source>
        <translation>Users</translation>
    </message>
    <message>
        <source>Open direct chat</source>
        <translation>Open direct chat</translation>
    </message>
    <message>
        <source>Mention user</source>
        <translation>Mention user</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Search</translation>
    </message>
    <message>
        <source>Ignore user</source>
        <translation>Ignore user</translation>
    </message>
    <message>
        <source>Kick user</source>
        <translation>Kick user</translation>
    </message>
    <message>
        <source>Ban user</source>
        <translation>Ban user</translation>
    </message>
    <message>
        <source>Kick %1</source>
        <translation>Kick %1</translation>
    </message>
    <message>
        <source>Reason</source>
        <translation>Reason</translation>
    </message>
    <message>
        <source>Ban %1</source>
        <translation>Ban %1</translation>
    </message>
    <message>
        <source>(%L1 out of %L2)</source>
        <translation>(%L1 out of %L2)</translation>
    </message>
</context>
<context>
    <name>FileContent</name>
    <message>
        <source>Size: %1, declared type: %2</source>
        <translation>Size: %1, declared type: %2</translation>
    </message>
    <message>
        <source>Open after downloading</source>
        <translation>Open after downloading</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation>Save as...</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Open folder</translation>
    </message>
    <message>
        <source>uploaded from %1</source>
        <translation>uploaded from %1</translation>
    </message>
    <message>
        <source>being uploaded from %1</source>
        <translation>being uploaded from %1</translation>
    </message>
    <message>
        <source>downloaded to %1</source>
        <translation>downloaded to %1</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unknown</translation>
    </message>
    <message numerus="yes">
        <source>%Ln byte(s)</source>
        <translation>
            <numerusform>%Ln byte</numerusform>
            <numerusform>%Ln bytes</numerusform>
        </translation>
    </message>
    <message>
        <source>%L1 kB</source>
        <translation>%L1 kB</translation>
    </message>
    <message>
        <source>%L1 MB</source>
        <translation>%L1 MB</translation>
    </message>
    <message>
        <source>%L1 GB</source>
        <translation>%L1 GB</translation>
    </message>
</context>
<context>
    <name>TimelineItem</name>
    <message>
        <source>Resend</source>
        <translation>Resend</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation>Discard</translation>
    </message>
    <message>
        <source>edited</source>
        <translation>edited</translation>
    </message>
    <message>
        <source>Go to
older room</source>
        <translation>Go to
older room</translation>
    </message>
    <message>
        <source>Go to
new room</source>
        <translation>Go to
new room</translation>
    </message>
    <message>
        <source>Reaction &apos;%1&apos; from %2</source>
        <translation>Reaction &apos;%1&apos; from %2</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Quaternion - an IM client for the Matrix protocol</source>
        <translation>Quaternion - an IM client for the Matrix protocol</translation>
    </message>
    <message>
        <source>Override locale</source>
        <translation>Override locale</translation>
    </message>
    <message>
        <source>locale</source>
        <translation>locale</translation>
    </message>
    <message>
        <source>Hide main window on startup</source>
        <translation>Hide main window on startup</translation>
    </message>
</context>
<context>
    <name>SystemTrayIcon</name>
    <message>
        <source>Highlight in %1</source>
        <translation>Highlight in %1</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Hide</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quit</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Show</translation>
    </message>
    <message numerus="yes">
        <source>%Ln highlight(s)</source>
        <translation>
            <numerusform>%Ln highlight</numerusform>
            <numerusform>%Ln highlights</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln unread message(s) across all rooms</source>
        <translation>
            <numerusform>%Ln unread messages across all rooms</numerusform>
            <numerusform>%Ln unread messages across all rooms</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TimelineWidget</name>
    <message>
        <source>Referenced message not found</source>
        <translation>Referenced message not found</translation>
    </message>
    <message>
        <source>Copy permalink to clipboard</source>
        <translation>Copy permalink to clipboard</translation>
    </message>
    <message>
        <source>Show details</source>
        <translation>Show details</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Open Folder</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Save file as...</source>
        <translation>Save file as...</translation>
    </message>
    <message>
        <source>Copy selected text to clipboard</source>
        <translation>Copy selected text to clipboard</translation>
    </message>
    <message>
        <source>Copy image to clipboard</source>
        <translation>Copy image to clipboard</translation>
    </message>
    <message>
        <source>Save file as</source>
        <translation>Save file as</translation>
    </message>
    <message>
        <source>Redact</source>
        <translation>Redact</translation>
    </message>
    <message>
        <source>Copy link to clipboard</source>
        <translation>Copy link to clipboard</translation>
    </message>
    <message>
        <source>Quote</source>
        <translation>Quote</translation>
    </message>
    <message>
        <source>Open externally</source>
        <translation>Open externally</translation>
    </message>
</context>
<context>
    <name>ProfileDialog</name>
    <message>
        <source>Device display name</source>
        <translation>Device display name</translation>
    </message>
    <message>
        <source>Device ID</source>
        <translation>Device ID</translation>
    </message>
    <message>
        <source>Last time seen</source>
        <translation>Last time seen</translation>
    </message>
    <message>
        <source>Last IP address</source>
        <translation>Last IP address</translation>
    </message>
    <message>
        <source>User profiles</source>
        <translation>User profiles</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Account</translation>
    </message>
    <message>
        <source>Display Name</source>
        <translation>Display Name</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copy to clipboard</translation>
    </message>
    <message>
        <source>Access token</source>
        <translation>Access token</translation>
    </message>
    <message>
        <source>Loading other devices...</source>
        <translation>Loading other devices...</translation>
    </message>
    <message>
        <source>No avatar</source>
        <translation>No avatar</translation>
    </message>
    <message>
        <source>Set avatar</source>
        <translation>Set avatar</translation>
    </message>
    <message>
        <source>Verification timed out</source>
        <translation>Verification timed out</translation>
    </message>
    <message>
        <source>Verification was cancelled</source>
        <translation>Verification was cancelled</translation>
    </message>
    <message>
        <source>Verification did not succeed</source>
        <translation>Verification did not succeed</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Please accept the verification request on the device you want to verify</source>
        <translation>Please accept the verification request on the device you want to verify</translation>
    </message>
    <message>
        <source>This device</source>
        <translation>This device</translation>
    </message>
    <message>
        <source>Verified</source>
        <translation>Verified</translation>
    </message>
    <message>
        <source>Verify...</source>
        <translation>Verify...</translation>
    </message>
    <message>
        <source>No E2EE</source>
        <translation>No E2EE</translation>
    </message>
    <message>
        <source>Verification failed: icons did not match</source>
        <translation>Verification failed: icons did not match</translation>
    </message>
    <message>
        <source>Verification was cancelled on the other side</source>
        <translation>Verification was cancelled on the other side</translation>
    </message>
</context>
<context>
    <name>Timeline</name>
    <message>
        <source>Latest events</source>
        <translation>Latest events</translation>
    </message>
    <message numerus="yes">
        <source>%Ln events back from now</source>
        <translation>
            <numerusform>%Ln events back from now</numerusform>
            <numerusform>%Ln events back from now</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln events cached</source>
        <translation>
            <numerusform>%Ln event cached</numerusform>
            <numerusform>%Ln events cached</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln events requested from the server</source>
        <translation>
            <numerusform>%Ln event requested from the server</numerusform>
            <numerusform>%Ln events requested from the server</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ChatEdit</name>
    <message>
        <source>Reset formatting</source>
        <translation>Reset formatting</translation>
    </message>
    <message>
        <source>Reset the current character formatting to the default</source>
        <translation>Reset the current character formatting to the default</translation>
    </message>
    <message>
        <source>Paste as rich text</source>
        <translation>Paste as rich text</translation>
    </message>
    <message>
        <source>Paste as plain text</source>
        <translation>Paste as plain text</translation>
    </message>
</context>
<context>
    <name>DockModeMenu</name>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Off</translation>
    </message>
    <message>
        <source>&amp;Docked</source>
        <translation>&amp;Docked</translation>
    </message>
    <message>
        <source>&amp;Floating</source>
        <translation>&amp;Floating</translation>
    </message>
    <message>
        <source>Completely hide this list</source>
        <translation>Completely hide this list</translation>
    </message>
    <message>
        <source>The list is shown within the main window</source>
        <translation>The list is shown within the main window</translation>
    </message>
    <message>
        <source>The list is shown separately from the main window</source>
        <translation>The list is shown separately from the main window</translation>
    </message>
</context>
<context>
    <name>RoomHeader</name>
    <message>
        <source>(no name)</source>
        <translation>(no name)</translation>
    </message>
    <message>
        <source>This room has been upgraded.</source>
        <translation>This room has been upgraded.</translation>
    </message>
    <message>
        <source>Unstable room version!</source>
        <translation>Unstable room version!</translation>
    </message>
    <message>
        <source>(no topic)</source>
        <translation>(no topic)</translation>
    </message>
    <message>
        <source>Hide topic</source>
        <translation>Hide topic</translation>
    </message>
    <message>
        <source>Show topic</source>
        <translation>Show topic</translation>
    </message>
    <message>
        <source>Room
settings</source>
        <translation>Room
settings</translation>
    </message>
    <message>
        <source>Go to
new room</source>
        <translation>Go to
new room</translation>
    </message>
</context>
<context>
    <name>VerificationDialog</name>
    <message>
        <source>Verifying device %1</source>
        <translation>Verifying device %1</translation>
    </message>
    <message>
        <source>They match</source>
        <translation>They match</translation>
    </message>
    <message>
        <source>They DON&apos;T match</source>
        <translation>They DON&apos;T match</translation>
    </message>
    <message>
        <source>Confirm that the same icons, in the same order are displayed on the other side</source>
        <translation>Confirm that the same icons, in the same order are displayed on the other side</translation>
    </message>
</context>
</TS>
